---
layout: collection
title: Plan Wireless Sites
description: A worksheet to use when visiting a possible router installation site, with examples on how to best fill it out.
site_section: docs
pdf: cck/building-mounting/Plan-Wireless-Sites.pdf
files:
 "Network Site Worksheet": /files/cck/building-mounting/Network-site-worksheet.pdf
 "Site Worksheet Examples": /files/cck/building-mounting/Site-worksheet-examples.pdf
 "Production files": /files/cck/building-mounting/Plan-wireless-sites-production-files.zip
created: 2015-05-05
changed: 2015-05-05
post_author: Andy Gunn
lang: en
---
![Plan Wireless Sites intro graphic](/files/Plan_wireless_sites_graphic.png "Intro graphic")

## Introduction

When it comes time to design and build your community wireless network, it is helpful to have as much detail about each installation site before you visit. The document below describes some helpful tips for router placement on, in, and around buildings based on what those routers do. After that, there is a [Network Site Worksheet](/files/cck/building-mounting/Network-site-worksheet.pdf) to download and use when surveying sites for installations. To best use this worksheet, there are [examples](/files/cck/building-mounting/Site-worksheet-examples.pdf) of different types of sites and how to use the worksheet.

This process should normally come after you [Inventory the Neighborhood](/docs/cck/planning/inventory-the-neighborhood/), and decide what sites seem best. The worksheets will give you the necessary detail to see what sites can connect, what types of routers you should use, and what hardware and tools the site installation will require.

A Build-It-Ourselves Guide to Community Networks Reading through this document and the worksheet examples should take about 30 to 45 minutes. Visiting a possible installation site to fill out the worksheet may take up to an hour, depending on the size of the site, and the difficulty to reach different areas of the site.


### MATERIALS + SUPPLIES NEEDED

* PDF or printed versions of the [Network Site Worksheet](/files/cck/building-mounting/Network-site-worksheet.pdf) and [Site Worksheet Examples](/files/cck/building-mounting/Site-worksheet-examples.pdf).
* Pens or color markers.


## Router Placement

Wireless signals, such as the Wi-Fi signals used in community wireless networks, travel by line of sight. If two routers have a building or trees between them, the signals will be blocked and they will be unable to communicate. For this reason, wireless networking equipment needs to be mounted on tall towers or high rooftops to link homes and businesses together. The downside of this is that people on the ground may have a hard time connecting to these somewhat far away nodes.

A common method for designing networks (such as the Internet!) is to build it in layers:

* The top or highest layer has the fastest connections, and provides the core connectivity. In a neighborhood or town network, the core would connect distant parts together.
* The middle layers have fast connections, but also distribute or move large amounts of traffic from people using the network to the core layer, which then connects out to the Internet.
* The lowest layer provides access to people using the network. You would connect your phone, tablet or laptop to an Access Point, which in turn is connected to the distribution layer, and out to the Internet. Wireless networks can be designed in the same way, and in the case of community networks, using multiple layers can lead to better performance and more capacity on the network.


### Core Connections - Equipment Mounted Higher

![Core network layer](/files/Network_layer_rooftop.png "Equipment mounted on high rooftops")

The wireless signals can go further, thereby covering more area and linking parts of the neighborhood or town together. Directional routers can be used for more direct point-to-point links, adding capacity in sections of the neighborhood or town. Equipment mounted very high up doesn’t provide a good connection for the people on the ground or inside of the buildings.


### Access Connections - Equipment Mounted Lower

![Access network layer](/files/Network_layer_street.png "Equipment mounted for user access")

Wireless routers close to the ground provide better coverage so people can connect their phones, tablets or laptops to the network. Often times, these routers can be replaced with simple low-cost Access Point devices, and allow the higher layers to determine how the connect to the rest of the network.


### Distributing Connections - Equipment in the Middle

![Distribution network layer](/files/Network_layer_middle.png "Equipment connecting the core to the access network")

There are many ways to connect from the top of the network to the bottom. Cables can run from the top layer to Access Points where users connect, or there could be a cluster of mesh nodes wirelessly distributing access to a section of a neighborhood. In other cases, point-to-point or point-to-multipoint (common Wireless Internet Service Provider techniques) can be used to provide connections
to the Access connections.

For more details and activities on these types of connections, review [Types of Wireless Networks](/docs/cck/networking/types-of-wireless-networks/).


## Site planning worksheets

![Site worksheet examples graphic](/files/Site_worksheet_examples.png "Site Worksheet examples graphic")

From here, you can start taking a closer look at the sites you are planning to install your community network equipment in and on. Consult the [Prep and Install Rooftop nodes](/docs/cck/building-mounting/prep-install-rooftop-nodes/), [Learn Rooftop Basics](/docs/cck/building-mounting/learn-rooftop-basics/), and [Learn About Rooftop Mounts](/docs/cck/building-mounting/learn-about-rooftop-mounts/) documents if you are still looking for more tips on installing on rooftops.

For the most part, installing wireless equipment on rooftops and indoors should be common sense. When you visit a site it will most likely be very clear where the best spot for the equipment will be, where the cables can be run, and where the indoor access points will go so people can access the network.

Download the [Network Site Worksheet](/files/cck/building-mounting/Network-site-worksheet.pdf) and print enough copies for the sites you will visit and install. Look through the [Site Worksheet Examples](/files/cck/building-mounting/Site-worksheet-examples.pdf) to get an idea of what to look for, and how to fill them out.


## Definitions

**AP (Access Point):** A device that allows wireless devices to connect to a wired network using Wi-Fi or related standards.

**Ethernet:** A type of networking protocol - it defines the types of cables and connections that are used to wire computers, switches, and routers together. Most often Ethernet cabling is Category 5 or 6, made up of twisted pair wiring similar to phone cables.

**Line of Sight:** An unobstructed path for wireless signals to travel between buildings or devices.

**Mast:** A metal pipe or pole used to mount equipment. It is usually 1 & 1/2" (4cm) in diameter, and around 5 feet (1.5 meters) long. Antenna masts will often have one tapered end so they can be stacked to form taller masts.

**Site:** A location in a neighborhood or community to place wireless equipment.


## Related Information

As mentioned above, there are a number of other documents related to site planning and installation in the **Planning** and **Building + Mounting** sections. You can start with [Inventory the Neighborhood](/docs/cck/planning/inventory-the-neighborhood/), then explore [Learn Rooftop Basics](/docs/cck/building-mounting/learn-rooftop-basics/) and [Prep and Install Rooftop nodes](/docs/cck/building-mounting/prep-install-rooftop-nodes/) before using the worksheets discussed here.

You can also consult [Common Hardware Setups](/docs/cck/installing-configuring/common-hardware-setups/) and [Advanced Hardware Setups](/docs/cck/installing-configuring/advanced-hardware-setups/) for more examples on how to connect wireless equipment together for community networking. In addition, [Types of Wireless Networks](/docs/cck/networking/types-of-wireless-networks/) details more methods for connecting your neighbors!

